==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectRelatedWhereSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhere;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class SelectRelatedWhereSetImpl extends InstanceSet<SelectRelatedWhereSet,SelectRelatedWhere> implements SelectRelatedWhereSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectRelatedWhere selectrelatedwhere : this ) selectrelatedwhere.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setWhere_Clause_Value_ID( UniqueId ref_Where_Clause_Value_ID ) throws XtumlException {
        for ( SelectRelatedWhere selectrelatedwhere : this ) selectrelatedwhere.setWhere_Clause_Value_ID( ref_Where_Clause_Value_ID );
    }


    // selections
    @Override
    public ValueSet R611_where_clause_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SelectRelatedWhere selectrelatedwhere : this ) valueset.add( selectrelatedwhere.R611_where_clause_Value() );
        return valueset;
    }
    @Override
    public ACT_SELSet R664_is_a_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( SelectRelatedWhere selectrelatedwhere : this ) act_selset.add( selectrelatedwhere.R664_is_a_ACT_SEL() );
        return act_selset;
    }


    @Override
    public SelectRelatedWhere nullElement() {
        return SelectRelatedWhereImpl.EMPTY_SELECTRELATEDWHERE;
    }

    @Override
    public SelectRelatedWhereSet emptySet() {
      return new SelectRelatedWhereSetImpl();
    }

    @Override
    public SelectRelatedWhereSet value() {
        return this;
    }

    @Override
    public List<SelectRelatedWhere> elements() {
        return Arrays.asList(toArray(new SelectRelatedWhere[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/SelectRelatedWhereSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhere;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_SELSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SelectRelatedWhereSetImpl extends InstanceSet<SelectRelatedWhereSet,SelectRelatedWhere> implements SelectRelatedWhereSet {

    public SelectRelatedWhereSetImpl() {
    }

    public SelectRelatedWhereSetImpl(Comparator<? super SelectRelatedWhere> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setWhere_Clause_Value_ID( UniqueId ref_Where_Clause_Value_ID ) throws XtumlException {
        for ( SelectRelatedWhere selectrelatedwhere : this ) selectrelatedwhere.setWhere_Clause_Value_ID( ref_Where_Clause_Value_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( SelectRelatedWhere selectrelatedwhere : this ) selectrelatedwhere.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ValueSet R611_where_clause_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SelectRelatedWhere selectrelatedwhere : this ) valueset.add( selectrelatedwhere.R611_where_clause_Value() );
        return valueset;
    }
    @Override
    public ACT_SELSet R664_is_a_ACT_SEL() throws XtumlException {
        ACT_SELSet act_selset = new ACT_SELSetImpl();
        for ( SelectRelatedWhere selectrelatedwhere : this ) act_selset.add( selectrelatedwhere.R664_is_a_ACT_SEL() );
        return act_selset;
    }


    @Override
    public SelectRelatedWhere nullElement() {
        return SelectRelatedWhereImpl.EMPTY_SELECTRELATEDWHERE;
    }

    @Override
    public SelectRelatedWhereSet emptySet() {
      return new SelectRelatedWhereSetImpl();
    }

    @Override
    public SelectRelatedWhereSet emptySet(Comparator<? super SelectRelatedWhere> comp) {
      return new SelectRelatedWhereSetImpl(comp);
    }

    @Override
    public SelectRelatedWhereSet value() {
        return this;
    }

    @Override
    public List<SelectRelatedWhere> elements() {
        return Arrays.asList(toArray(new SelectRelatedWhere[0]));
    }

}
